From a18ba38582045b5428a6d34e7ee56bbf64522e16 Mon Sep 17 00:00:00 2001
From: Francois-Rene Rideau <fare@tunes.org>
Date: Thu, 27 Oct 2011 15:45:02 -0400
Subject: [PATCH 2/3] Make sure we always send a cooked message, even for code with just a reason-phrase,
 even for code without a reason-phrase at all.
 Some deleted whitespace.

---
 acceptor.lisp |   24 ++++++++++++++----------
 1 files changed, 14 insertions(+), 10 deletions(-)

diff --git a/acceptor.lisp b/acceptor.lisp
index b0332b7..2768f42 100644
--- a/acceptor.lisp
+++ b/acceptor.lisp
@@ -257,7 +257,7 @@ Might be a good place for around methods specialized for your subclass
 of ACCEPTOR which bind or rebind special variables which can then be
 accessed by your handlers."))
 
-(defgeneric acceptor-ssl-p (acceptor) 
+(defgeneric acceptor-ssl-p (acceptor)
   (:documentation "Returns a true value if ACCEPTOR uses SSL
 connections.  The default is to unconditionally return NIL and
 subclasses of ACCEPTOR must specialize this method to signal that
@@ -279,7 +279,7 @@ they're using secure connections - see the SSL-ACCEPTOR class."))
   (when soft
     (with-lock-held ((acceptor-shutdown-lock acceptor))
       (when (plusp (accessor-requests-in-progress acceptor))
-        (condition-variable-wait (acceptor-shutdown-queue acceptor) 
+        (condition-variable-wait (acceptor-shutdown-queue acceptor)
                                  (acceptor-shutdown-lock acceptor)))))
   (#+:lispworks close
    #-:lispworks usocket:socket-close
@@ -395,7 +395,7 @@ chunked encoding, but acceptor is configured to not use it.")))))
           (force-output *hunchentoot-stream*))
         (ignore-errors*
           (close *hunchentoot-stream* :abort t))))))
-  
+
 (defmethod acceptor-ssl-p ((acceptor t))
   ;; the default is to always answer "no"
   nil)
@@ -478,7 +478,7 @@ catches during request processing."
        (return))
      (when (usocket:wait-for-input listener :ready-only t :timeout +new-connection-wait-time+)
        (when-let (client-connection
-                  (handler-case (usocket:socket-accept listener)                               
+                  (handler-case (usocket:socket-accept listener)
                     ;; ignore condition
                     (usocket:connection-aborted-error ())))
          (set-timeouts client-connection
@@ -611,17 +611,21 @@ handler."
                            (escape-for-html (princ-to-string error))
                            (when *show-lisp-backtraces-p*
                              (escape-for-html (princ-to-string backtrace))))
-           (cooked-message "An error has occured"))))))
+           (cooked-message "An error has occurred")))
+      (t
+         (cooked-message "An error has occurred")))))
 
 (defmethod acceptor-status-message ((acceptor t) http-status-code &rest args &key &allow-other-keys)
   (apply 'make-cooked-message http-status-code args))
 
 (defmethod acceptor-status-message :around ((acceptor acceptor) http-status-code &rest args &key &allow-other-keys)
-  (handler-case
-      (call-next-method)
-    (error (e)
-      (log-message* :error "error ~A during error processing, sending cooked message to client" e)
-      (apply 'make-cooked-message http-status-code args))))
+  (flet ((fallback ()
+           (apply 'make-cooked-message http-status-code args)))
+    (handler-case
+        (or (call-next-method) (fallback))
+      (error (e)
+        (log-message* :error "error ~A during error processing, sending cooked message to client" e)
+        (fallback)))))
 
 (defun string-as-keyword (string)
   "Intern STRING as keyword using the reader so that case conversion is done with the reader defaults."
-- 
1.7.2.5

